summaryrefslogtreecommitdiff
path: root/lib/Target/X86/X86.h
diff options
context:
space:
mode:
authorChris Lattner <sabre@nondot.org>2003-07-26 23:49:58 +0000
committerChris Lattner <sabre@nondot.org>2003-07-26 23:49:58 +0000
commitd281de21815d4766cf4960ad2ef075bee3beac0b (patch)
tree53af54b30520d108ba121a743f596aa9965ba715 /lib/Target/X86/X86.h
parent1194e9501984daf0d3237ed1bf18a156173e7fd4 (diff)
downloadllvm-d281de21815d4766cf4960ad2ef075bee3beac0b.tar.gz
llvm-d281de21815d4766cf4960ad2ef075bee3beac0b.tar.bz2
llvm-d281de21815d4766cf4960ad2ef075bee3beac0b.tar.xz
Rename function to be more consistent with filename
git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@7352 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'lib/Target/X86/X86.h')
-rw-r--r--lib/Target/X86/X86.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/Target/X86/X86.h b/lib/Target/X86/X86.h
index 81c68da58e..3decdfd209 100644
--- a/lib/Target/X86/X86.h
+++ b/lib/Target/X86/X86.h
@@ -12,11 +12,11 @@
class TargetMachine;
class Pass;
/// createSimpleX86InstructionSelector - This pass converts an LLVM function
/// into a machine code representation is a very simple peep-hole fashion. The
/// generated code sucks but the implementation is nice and simple.
///
-Pass *createSimpleX86InstructionSelector(TargetMachine &TM);
+Pass *createX86SimpleInstructionSelector(TargetMachine &TM);
/// createX86PeepholeOptimizer - Create a pass to perform X86 specific peephole
/// optimizations.
@@ -12,11 +12,11 @@
class TargetMachine;
class Pass;
-/// createSimpleX86InstructionSelector - This pass converts an LLVM function
+/// createX86SimpleInstructionSelector - This pass converts an LLVM function
/// into a machine code representation is a very simple peep-hole fashion. The
/// generated code sucks but the implementation is nice and simple.